@@ -3,7 +3,7 @@
 import platform
 import sys
 
-PYMUMBLE_VERSION = "1.3.1"
+PYMUMBLE_VERSION = "1.5"
 
 # ============================================================================
 # Tunable parameters
@@ -35,7 +35,7 @@ PYMUMBLE_CONN_STATE_NOT_CONNECTED = 0
 PYMUMBLE_CONN_STATE_AUTHENTICATING = 1
 PYMUMBLE_CONN_STATE_CONNECTED = 2
 PYMUMBLE_CONN_STATE_FAILED = 3
-        
+
 # Mumble control messages types
 PYMUMBLE_MSG_TYPES_VERSION = 0
 PYMUMBLE_MSG_TYPES_UDPTUNNEL = 1
@@ -66,15 +66,17 @@ PYMUMBLE_MSG_TYPES_SERVERCONFIG = 24
 # callbacks names
 PYMUMBLE_CLBK_CONNECTED = "connected"
 PYMUMBLE_CLBK_DISCONNECTED = "disconnected"
-PYMUMBLE_CLBK_CHANNELCREATED = "channel_created" 
+PYMUMBLE_CLBK_CHANNELCREATED = "channel_created"
 PYMUMBLE_CLBK_CHANNELUPDATED = "channel_updated"
 PYMUMBLE_CLBK_CHANNELREMOVED = "channel_remove"
 PYMUMBLE_CLBK_USERCREATED = "user_created"
 PYMUMBLE_CLBK_USERUPDATED = "user_updated"
-PYMUMBLE_CLBK_USERREMOVED = "user_remove"
+PYMUMBLE_CLBK_USERREMOVED = "user_removed"
 PYMUMBLE_CLBK_SOUNDRECEIVED = "sound_received"
 PYMUMBLE_CLBK_TEXTMESSAGERECEIVED = "text_received"
 PYMUMBLE_CLBK_CONTEXTACTIONRECEIVED = "contextAction_received"
+PYMUMBLE_CLBK_ACLRECEIVED = "acl_received"
+PYMUMBLE_CLBK_PERMISSIONDENIED = "permission_denied"
 
 # audio types
 PYMUMBLE_AUDIO_TYPE_CELT_ALPHA = 0
@@ -89,3 +91,6 @@ PYMUMBLE_CMD_MOVE = "move"
 PYMUMBLE_CMD_MODUSERSTATE = "update_user"
 PYMUMBLE_CMD_TEXTMESSAGE = "text_message"
 PYMUMBLE_CMD_TEXTPRIVATEMESSAGE = "text_private_message"
+PYMUMBLE_CMD_CHANNELUNLINK = "unlink"
+PYMUMBLE_CMD_QUERYACL = "get_acl"
+PYMUMBLE_CMD_REMOVEUSER = "remove_user"
