@@ -69,7 +69,7 @@ class Mumble(threading.Thread):
         self.tokens = tokens
         self.__opus_profile = PYMUMBLE_AUDIO_TYPE_OPUS_PROFILE
         self.stereo = stereo
-        
+
         if stereo:
             self.Log.debug("Working in STEREO mode.")
         else:
@@ -86,6 +86,8 @@ class Mumble(threading.Thread):
         self.ready_lock = threading.Lock()  # released when the connection is fully established with the server
         self.ready_lock.acquire()
 
+        self.positional = None
+
     def init_connection(self):
         """Initialize variables that are local to a connection, (needed if the client automatically reconnect)"""
         self.ready_lock.acquire(False)  # reacquire the ready-lock in case of reconnection
@@ -187,7 +189,7 @@ class Mumble(threading.Thread):
         waiting for a message from the server for maximum self.loop_rate time
         take care of sending the ping
         take care of sending the queued commands to the server
-        check on every iteration for outgoing sound 
+        check on every iteration for outgoing sound
         check for disconnection
         """
         self.Log.debug("entering loop")
@@ -326,8 +328,8 @@ class Mumble(threading.Thread):
 
             if self.connected == PYMUMBLE_CONN_STATE_AUTHENTICATING:
                 self.connected = PYMUMBLE_CONN_STATE_CONNECTED
-                self.callbacks(PYMUMBLE_CLBK_CONNECTED)
                 self.ready_lock.release()  # release the ready-lock
+                self.callbacks(PYMUMBLE_CLBK_CONNECTED)
 
         elif type == PYMUMBLE_MSG_TYPES_CHANNELREMOVE:
             mess = mumble_pb2.ChannelRemove()
@@ -374,11 +376,15 @@ class Mumble(threading.Thread):
             mess.ParseFromString(message)
             self.Log.debug("message: PermissionDenied : %s", mess)
 
+            self.callbacks(PYMUMBLE_CLBK_PERMISSIONDENIED, mess)
+
         elif type == PYMUMBLE_MSG_TYPES_ACL:
             mess = mumble_pb2.ACL()
             mess.ParseFromString(message)
             self.Log.debug("message: ACL : %s", mess)
 
+            self.callbacks(PYMUMBLE_CLBK_ACLRECEIVED, mess)
+
         elif type == PYMUMBLE_MSG_TYPES_QUERYUSERS:
             mess = mumble_pb2.QueryUsers()
             mess.ParseFromString(message)
@@ -511,7 +517,7 @@ class Mumble(threading.Thread):
 
                     if newsound is None:  # In case audio have been disable for specific users
                         return
-                    
+
                     self.callbacks(PYMUMBLE_CLBK_SOUNDRECEIVED, self.users[session.value], newsound)
 
                     sequence.value += int(round(newsound.duration / 1000 * 10))  # add 1 sequence per 10ms of audio
@@ -526,7 +532,6 @@ class Mumble(threading.Thread):
                 #                raise InvalidFormatError("Invalid audio frame size")
 
             pos += size  # go further in the packet, after the audio frame
-
         # TODO: get position info
 
     def set_application_string(self, string):
@@ -543,7 +548,7 @@ class Mumble(threading.Thread):
 
     def set_codec_profile(self, profile):
         """set the audio profile"""
-        if profile in ["audio", "voip"]:
+        if profile in ["audio", "voip", "restricted_lowdelay"]:
             self.__opus_profile = profile
         else:
             raise ValueError("Unknown profile: " + str(profile))
@@ -617,6 +622,14 @@ class Mumble(threading.Thread):
             self.send_message(PYMUMBLE_MSG_TYPES_CHANNELREMOVE, channelremove)
             cmd.response = True
             self.commands.answer(cmd)
+        elif cmd.cmd == PYMUMBLE_CMD_CHANNELUNLINK:
+            channelstate = mumble_pb2.ChannelState()
+            channelstate.channel_id = cmd.parameters["channel_id"]
+            for remove_id in cmd.parameters["remove_ids"]:
+                channelstate.links_remove.append(remove_id)
+            self.send_message(PYMUMBLE_MSG_TYPES_CHANNELSTATE, channelstate)
+            cmd.response = True
+            self.commands.answer(cmd)
         elif cmd.cmd == PYMUMBLE_MSG_TYPES_VOICETARGET:
             textvoicetarget = mumble_pb2.VoiceTarget()
             textvoicetarget.id = cmd.parameters["id"]
@@ -656,10 +669,27 @@ class Mumble(threading.Thread):
                 userstate.texture = cmd.parameters["texture"]
             if "user_id" in cmd.parameters:
                 userstate.user_id = cmd.parameters["user_id"]
+            if "plugin_context" in cmd.parameters:
+                userstate.plugin_context = cmd.parameters["plugin_context"]
 
             self.send_message(PYMUMBLE_MSG_TYPES_USERSTATE, userstate)
             cmd.response = True
             self.commands.answer(cmd)
+        elif cmd.cmd == PYMUMBLE_CMD_REMOVEUSER:
+            userremove = mumble_pb2.UserRemove()
+            userremove.session = cmd.parameters["session"]
+            userremove.reason = cmd.parameters["reason"]
+            userremove.ban = cmd.parameters["ban"]
+            self.send_message(PYMUMBLE_MSG_TYPES_USERREMOVE, userremove)
+            cmd.response = True
+            self.commands.answer(cmd)
+        elif cmd.cmd == PYMUMBLE_CMD_QUERYACL:
+            acl = mumble_pb2.ACL()
+            acl.channel_id = cmd.parameters["channel_id"]
+            acl.query = True
+            self.send_message(PYMUMBLE_MSG_TYPES_ACL, acl)
+            cmd.response = True
+            self.commands.answer(cmd)
 
     def get_max_message_length(self):
         return self.server_max_message_length
@@ -669,7 +699,10 @@ class Mumble(threading.Thread):
 
     def my_channel(self):
         return self.channels[self.users.myself["channel_id"]]
-    
+
+    def denial_type(self, n):
+        return mumble_pb2.PermissionDenied.DenyType.Name(n)
+
     def stop(self):
         self.reconnect = None
         self.exit = True
